@import 'charts.css';
@import url(//netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css);
@import url(//fonts.googleapis.com/css?family=Lato:400,700);
@import url(//fonts.googleapis.com/css?family=Merriweather);

/*
teals: #02aeab; #027b7a; #014948;
tans: #f7f8f3; #eff1e9; #e0e4d4; #cad0b5;
orange: #f55b2c
*/

*, *:before, *:after {
    -moz-box-sizing: border-box; -webkit-box-sizing: border-box; box-sizing: border-box;
}
    
html,
body {
    margin: 0;
    padding: 0;
    background-color: #f7f8f3;
    line-height: 1.4;
    font-size: 14px;
    font-family: "Lato", "Helvetica Neue", Helvetica, Arial, sans-serif;
}
html {
    background-color: #e0e4d4;
}
html,
button,
input,
select,
textarea {
    color: #222;
}
menu,
ol,
ul {
    padding: 0 0 0 2em;
}
input:focus {
    border: 1px solid #02aeab;
    -webkit-box-shadow: 0px 0px 2px rgba(1, 73, 72, 0.5);
    -moz-box-shadow: 0px 0px 2px rgba(1, 73, 72, 0.5);
    box-shadow: 0px 0px 2px rgba(1, 73, 72, 0.5);
}
::-moz-selection {
    background: #02aeab;
    text-shadow: none;
}
::selection {
    background: #02aeab;
    text-shadow: none;
}

hr {
    display: block;
    height: 1px;
    border: 0;
    border-top: 1px solid #fff;
    margin: 1em 0;
    padding: 0;
}

img {
    vertical-align: middle;
}

fieldset {
    border: 0;
    margin: 0;
    padding: 0;
}

textarea {
    resize: vertical;
}

.chromeframe {
    margin: 0.2em 0;
    background: #ccc;
    color: #000;
    padding: 0.2em 0;
}

/* BASIC ELEMENTS */
a {
    color: #014948;
}
a.permalink {
    text-decoration: none;
    color: inherit;
}
a:hover {
    color: #02aeab;
}
a.permalink span,
a.permalink i {
    color: #777;
    display: none;
}
a.permalink:hover {
    color: inherit;
}
a.permalink:hover span,
a.permalink:hover i {
    display: inherit;
}
p, .serif {
    font-family: "Merriweather", Georgia, serif;
    margin: 0 0 1em;
}
.caption {
    margin-top: .25em;
    padding-top: .25em;
    font-size: .83em;
    font-family: "Lato", "Helvetica Neue", Helvetica, Arial, sans-serif;
}
.caption-group {
    margin-right: 1em;
}

.display-type,
.leader {
    font-family: "Lato", "Helvetica Neue", Helvetica, Arial, sans-serif;
}
.leader {
    font-weight: bold;
    text-transform: uppercase;
}

h1, h2, h3, h4, h5, h6 {
    margin: 0;
    line-height: 1.2;
    font-weight: 700;
}
h1, h2, h3, .topic h2, .topic h4 {
    margin-bottom: .25em;
}
h1.title {
    font-size: 2.5em;
}
h2.subhead {
    font-size: 1.5em;
    line-height: 1.3;
    margin-bottom: .5em;
}
#table-display h4 {
    font-size: .9em;
}
.list-header {
    margin-bottom: .5em;
}
.ul-icon-list {
    list-style: none;
    padding: 0;
}
.ul-icon-list i {
    margin-right: .33em;
}
.ul-icon-list .fa {
    width: 16px;
    display: inline-block;
    text-align: center;
}
.ul-icon-list a,
footer ul a {
    text-decoration: none;
}
.ul-icon-list a:hover,
footer ul a:hover {
    text-decoration: underline;
}
.option-group {
    font-size: .9em;
    margin-bottom: 1.5em;
}
.option-list {
    list-style: none;
    margin: .33em 0 0 1em;
    padding: 0;
}
.option-list li {
    margin-bottom: .33em;
}
.option-header {
    margin-bottom: .25em;
}
img.screenshot {
    border: 1px solid #cad0b5;
    width: 100%;
}

/* LAYOUT */
#page-header,
.box-header {
    background-color: #014948;
}
#page-header .wrapper {
    padding: .5em 0;
}
#page-header-title a,
.box-header a {
    color: #f7f8f3;
    text-decoration: none;
}
#page-header-title a.title {
    font-size: 21px;
}
#page-header-title img,
.box-header img {
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    margin: 0 3px 0 0;
    vertical-align: baseline;
    height: 21px;
}
.box-header {
    padding: .25em .5em;
    margin-bottom: .67em;
}
.box-header img {
    height: 16px;
}
.box-header a {
    font-size: 16px;
}
.box-content {
    padding: 0 1em;
    margin-bottom: .67em;
}
.box-content section {
    margin-bottom: 0;
}

#menu {
    float: right;
    margin: .2em 0 0;
    padding: 0;
}
#menu .tool-group {
    margin-right: 0;
}
#menu .separator {
    float:left;
    color: #fff;
    font-size: .83em;
    width: 3em;
    text-align: center;
    height: 2em;
    padding-top: .2em;
}
#menu input {
    border: 0;
    margin-left: 0;
    padding: 2px 6px 0;
    height: 2em;
    line-height: 2em;
}
#menu a.button,
a.action-button,
.big-action .with-submit input[type="submit"] {
    color: #fff;
    display: block;
    margin-top: 0;
    padding: 0 9px;
    height: 2em;
    line-height: 1.9em;
    background-color: #1a9d95;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    border: none;
}
#menu a.button i {
    position: absolute;
    right: .5em;
    top: .5em;
    opacity: .5;
    display: none;
}
#menu a.button:hover {
    background-color: #f55b2c;
}
#menu-toggle {
    float: right;
    font-size: 18px;
    margin-top: 2px;
    color: #67b3a3;
    line-height: 1;
    padding: .25em .33em .2em;
    background-color: #001716;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    cursor: pointer;
    display: none;
}
#menu-toggle.fa:before {
    cursor: pointer;
}

#page-footer {
    background-color: #e0e4d4;
    border-top: 1px solid #cad0b5;
    padding: 1.5em 0 4.5em;
}
#page-footer ul {
    margin: 0;
    padding-left: 1em;
}
#page-footer ul.ul-icon-list {
    padding-left: 0;
    line-height: 2;
}
.content-container {
    padding: 2em 0;
    clear: both;
}
.data-view .content-container {
    padding: 1em 0;
}
.header-container {
    padding: 2em 0 0;
    clear: both;
}
.content-container .header-container {
    padding-top: 1em;
}
#header-container h1 {
    padding-right: 370px;
}

article,
article.column-full {
    margin-bottom: 4em;
}
header.section-contents {
    float: left;
    width: 13em;
}
header.section-contents h1 {
    font-size: 1em;
    margin: 0;
    padding: .6em 0 .55em .8em;
    background-color: #eff1e9;
    -webkit-border-top-left-radius: 4px;
    -moz-border-radius-topleft: 4px;
    border-top-left-radius: 4px;
    -webkit-border-bottom-left-radius: 4px;
    -moz-border-radius-bottomleft: 4px;
    border-bottom-left-radius: 4px;
}
article .section-container {
    background-color: #fff;
    margin-left: 13em;
    padding: .6em 1.2em 1.2em;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    -webkit-border-top-left-radius: 0;
    -moz-border-radius-topleft: 0;
    border-top-left-radius: 0;
}
header.section-contents h1,
article .section-container,
.card {
    border-top: 1px solid #e8eadf;
    border-bottom: 1px solid #cad0b5;
}
.card {
    display: block;
    font-size: 1.2em;
    margin: 0;
    padding: 0;
    text-decoration: none;
    background-color: #e0e4d4;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
}
.card:hover {
    color: #111;
}
.card .caption {
    font-size: 1em;
    font-weight: bold;
    display: block;
    padding: .83em 1em;
    margin: 0;
}
.card .more {
    font-size: .83em;
    margin-left: .25em;
    color: #cc4c3f;
    white-space: nowrap;
}
.card:hover .more {
    color: #f55b2c;
}
.card-container .card {
    margin-bottom: 1.5em;
}
.card img {
    width: 100%;
    margin: 0;
}
.explain {
    font-size: .83em;
    padding: 0 1em;
}
.sidebar-block .explain {
    padding: .5em 0;
}
.typeahead-container .explain {
    clear: both;
    margin-top: .5em;
}
.sidebar-block {
    margin-bottom: 2em;
}
.sidebar-block ul {
    font-size: .83em;
    font-weight: bold;
}
.expanded-table ul {
    list-style: none;
    padding: 0;
    margin-top: .75em;
    font-size: .9em;
}
.preview-table ul {
    font-weight: normal;
    list-style: none;
    padding: 0;
    margin-bottom: 0;
    font-size: .8em;
}
.preview-table ul.open {
    margin-bottom: .5em;
}
.expanded-table ul li,
.preview-table ul li {
    margin-bottom: .2em;
}
.expand-preview {
    display: block;
    text-align: center;
    text-decoration: none;
    font-size: .83em;
    font-weight: bold;
    padding: .33em 0;
    border-top: 1px solid #E8EADF;
}

section {
    margin-bottom: 2em;
}
.wide-content {
    overflow-x: auto;
}
.section-container section {
    margin-bottom: 3em;
}
#profile .section-container section {
    margin-bottom: 2em;
}
.section-container section:last-child {
    margin-bottom: .5em;
}
header.section-contents h1,
section h2 {
    font-size: 1em;
    line-height: 1.3;
    margin-bottom: 1em;
}
header.section-contents h1 a {
    font-size: .83em;
    line-height: 1.6em;
    font-weight: normal;
    float: right;
    padding-right: 1em;
}

aside {
    float: left;
    margin-left: -14.4em;
    width: 13em;
    padding: .25em .67em .67em 1.1em;
}
aside h3 {
    font-size: .9em;
}
aside p,
aside ul {
    font-size: .83em;
}
aside ul {
    margin: .33em .67em .67em 1em;
    padding: 0;
}
aside ul.sumlev-list,
aside ul.search-filter-list {
    list-style: none;
    margin: 0.33em 0 .67em .67em;
    padding: 0;
}
aside ul.search-filter-list{
    margin-top: .67em;
}
aside ul.sumlev-list .remove,
aside ul.search-filter-list .remove {
    margin-left: .5em;
}
aside li {
    margin-bottom: .25em;
}
aside ul.sumlev-list li,
aside ul.search-filter-list li {
    line-height: 1.2;
    margin-bottom: .5em;
}
aside sup {
    font-size: 1.25em;
    top: -.125em;
}
aside .aside-block {
    margin: 1em 0 1.5em;
    clear: both;
}
.search-results aside .aside-block {
    margin: 0 0 2em;
}
aside .search input {
    font-size: .83em;
    margin: .33em 0 0;
    padding: .15em .5em 0;
    width: 100%;
}
aside #geography-add-parent {
    margin-bottom: .2em;
}
aside .action-button {
    font-size: .83em;
    display: block;
    margin-bottom: 1em;
}
.search-results aside {
    padding-top: 0;
}
.search-results aside .remove-filters {
    text-align: left;
    margin-top: -.33em;
}
aside#facets {
    margin-left: 0;
}
.with-facets {
    padding-left: 14.4em;
}
.wrapper {
    width: auto;
    margin: 0 1.5em;
}
.full-width {
    clear: both;
    width: 100%;
    margin: 0;
}

#cover-map {
    position: relative;
    height: 35em;
    margin-bottom: 2em;
}
#slippy-map {
    position: absolute;
    width: 100%;
    height: 100%;
    left: 0;
    top: 0;
}

#use-location {
    display: inline-block;
    font-size: .9em;
    padding: 0 9px;
    margin-right: .33em;
}

#address-search-message { display: none; margin-top: 1em;}

#address-search {
    font-size: 1em;
    width: 100%;
}

.zoom-to-layer {
    background-color: #a1d0c6;
    text-decoration: none;
    color: #888;
    margin-left: .67em;
    padding: .33em .4em;
    font-size: .9em;
    float: right;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    cursor: pointer;
}
.zoom-to-layer.active,
.zoom-to-layer:hover {
    background-color: #1a9d95;
    color: #fff;
}

#address-search-content.no-map .zoom-to-layer, #address-search-content.no-map .no-map-hide {
    display: none;
}

#cover-profile {
    position: relative;
}
#cover-profile article {
    margin-top: 3em;
    background-color: #fff;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    border: 1px solid #02aeab;
    padding: .67em 1.25em .33em;
}
#cover-profile ul {
    list-style: none;
    font-size: .83em;
}
#cover-profile strong {
    float: left;
    margin-right: .5em;
}
#cover-profile .header-extra-links ul {
    float: left;
    padding: 0;
    margin: .5em 0 1.5em;
}
.column-row {
    clear: both;
}
.column-full,
.column-half,
.column-third,
.column-two-thirds,
.column-quarter,
.column-three-quarters,
.column-golden-wide,
.column-golden-narrow {
    float: left;
    margin: 0 2% 0 0;
}
.header-for-columns {
    margin: 0 2% 1em 0;
}
.column-full {
    width: 98%;
}
.column-half {
    width: 48%;
}
.column-third {
    width: 31%;
}
.column-two-thirds {
    width: 65%;
}
.column-quarter {
    width: 23%;
}
.column-three-quarters {
    width: 73%;
}
.column-golden-wide {
    width: 58%;
}
.column-golden-narrow {
    width: 38%;
}

/* HOMEPAGE */
#homepage #blurb {
    margin-top: 3em;
}
#homepage .content-container,
#comparison-builder .content-container {
    padding: 2.5em 0;
}
.white-stripe {
    background-color: #fff;
}
.tan-stripe {
    background-color: #eff1e9;
}
h1.article-header {
    font-size: 3em;
    margin-bottom: .25em;
}
.data-builder h1.article-header,
.data-view h1.article-header,
#query-topic-picker h1,
#compare-place-picker h1 {
    font-size: 2.5em;
}
h1.article-header-right {
    text-align: right;
    padding-right: .1em;
}
#homepage .big-action h1 {
    float: left;
    width: 200px;
}
.data-builder h1 {
    float: none;
    text-align: left;
    padding-right: 0;
    width: auto;
}
.data-builder #explore-topic-picker h1:after {
    content: ' ACS data';
}

#explore-topic-metadata p {
    float: left;
    width: 260px;
    text-align: right;
    padding-top: .5em;
}
.big-action input,
#query-topic-picker input,
#compare-place-picker input {
    font-size: 1.6em;
    padding: .25em .5em 0;
    width: 100%;
}
.big-action .with-submit input[type="text"] {
    width: 88%;
}
.big-action .with-submit input[type="submit"] {
    width: 10%;
    margin-left: 1%;
    display: inline-block;
    height: 2.6em;
    font-size: 1.3em;
    font-family: "Lato", "Helvetica Neue", Helvetica, Arial, sans-serif;
}

#profile #query-topic-picker input,
#profile #compare-place-picker input,
#map-controls #query-topic-picker input {
    font-size: 1em;
}
#homepage .input-wrapper,
#homepage .input-wrapper {
    padding-top: .25em;
    padding-left: 230px;
}
#geography-select-wrapper .geolocate-only {
    width: 100%;
    margin: 1em auto;
}
#geography-select-wrapper .action-button {
    display: block;
    margin-left: 3em;
}

.trigger-highlight {
    float: left;
    padding-top: 1.2em;
    padding-right: 1em;
}
.map-marker-label{
    position: absolute;
    color: black;
    font-size: 11px;
    font-weight: bold;
    width: 150px;
}

.action-button i {
    margin-right: .33em;
}
#homepage #profile p.explain {
    margin-top: .83em;
    font-style: italic;
}
#homepage #topics header {
    margin-bottom: 1em;
}
#homepage #topics h2 {
    font-size: 1.5em;
}
#homepage #explore-topic-picker .primary-explainer {
    display: none;
}
#homepage #query-builder-bar {
    margin: 1.5em 0;
}
.big-action {
    clear: both;
    margin: 0 0 1em;
}
.big-action .help-text {
    margin: .67em 1em;
    font-size: 1em;
}
.big-action p.help-text {
    font-style: italic;
}
.or {
    font-family: "Merriweather", Georgia, serif;
    font-size: 1.1em;
    line-height: 1;
    padding: .7em 0;
    font-style: italic;
    width: 3em;
    float: left;
    text-align: center;
}
.callout {
    margin-top: 1.5em;
    margin-bottom: 1.5em;
    padding: 0;
}
.callout.with-icon {
    padding-left: 36px;
}
.callout h3 {
    font-size: 24px;
}
.callout i.fa {
    display: block;
    float: left;
    text-align: center;
    width: 28px;
    height: 28px;
    font-size: 14px;
    line-height: 28px;
    color: #fff;
    background-color: #014948;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    margin-left: -36px;
}
.callout p:last-child {
    margin-bottom: 0;
}
.tag {
    text-transform: uppercase;
    font-family: "Lato", "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-style: normal;
    color: #fff;
    font-size: .8em;
    padding: .15em .33em;
    background-color: #555c3b;
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
}

.search-result-item {
    margin: 0 0 2.5em;
}
.search-result-item p {
    margin: 0 0 .5em 0;
    font-size: 1.1em;
}
.pagination .action-button {
    width: 10em;
    margin-right: 1em;
    display: inline-block;
}
.pagination .action-button i {
    margin: 0 .33em;
}

/* STATS */
.stat {
    width: 100%;
    color: #111;
    margin: 0;
    padding: 0;
}
.stat:hover {
    color: #111;
}
.context,
.context-phrases {
    font-size: .9em;
    font-weight: 500;
    color: #777;
}
.data-drawer.grid {
    font-size: .83em;
    padding-top: 0;
}
.grid .name,
.grid .value,
.grid .context {
    display: inline-block;
}
.grid .name {
    font-weight: bold;
}
.grid .value {
    min-width: 7em;
    text-align: right;
    padding-right: 1em;
}
.grid .context {
    font-size: .9em;
    margin-bottom: -.1em;
    min-width: 4em;
}
.stat .context {
    margin-left: .33em;
    display: none;
}
.stat:hover .context {
    display: inline-block;
}
.stat:hover .secondary .context {
    display: block;
}
.context-phrases {
    display: block;
    list-style: none;
    padding: 0;
    margin: 0;
}
.context-phrases li {
    line-height: 1.4;
    margin-bottom: .5em;
}
.context-phrases strong {
    color: #666;
}
.stat .primary {
    display: block;
    margin-bottom: 1em;
}
.stat .primary .name {
    display: block;
    font-size: 1.2em;
    font-weight: 400;
    line-height: 1.3;
}
.stat .primary .context {
    font-size: .5em;
}
.stat .primary .value {
    display: block;
    font-size: 2.2em;
    line-height: 1;
    margin: 0 0 .1825em;
    font-weight: 700;
}
.stat .primary .value sup {
    font-size: .5em;
    vertical-align: middle;
    top: -.83em;
}
.stat .secondary {
    display: block;
}
#cover-profile .stat .secondary {
    margin-bottom: .67em;
}
.stat .secondary .value {
    font-size: 1.2em;
    font-weight: 700;
    margin-right: .1em;
}
.stat .secondary .context {
    margin: 0 0 .67em;
}
.secondary.stacked .name {
    display: block;
}
.stat-suffix {
    font-size: .5em;
}
.stat-row select {
    max-width: 100px;
    font-size: .8em;
}
.stat-row {
    border-top: 1px solid #eff1e9;
    padding-top: 2em;
}
.stat-row.grouped-row {
    border: none;
    padding-top: 0;
}
.stat-row:first-child {
    border-top: none;
    padding-top: 0;
}

/* SVG MAPS */
.svg-map {
    position: relative;
}
.svg-map .outline {
    fill: #f7f8f3;
    stroke: #cad0b5;
    stroke-width: 1.5px;
}
.svg-map .feature,
.svg-map .point {
    stroke: #001b1b;
    fill: #014948;
}
.svg-map .mesh {
    fill: none;
    stroke: #fff;
    stroke-width: .5px;
    stroke-linejoin: round;
}
.svg-map .geographies {
    fill: #e5e5e5;
    stroke: #fff;
    stroke-linejoin: round;
}
.push-right {
    margin-left: 1em;
}
.nudge-right {
    margin-left: .33em;
}
.context-block {
    display: block;
    margin: .25em 0;
}

.q0 { background-color: #d9ece8; fill: #d9ece8; } /* Swans Down*/
.q1 { background-color: #a1cfc6; fill: #a1cfc6; } /* Sinbad */
.q2 { background-color: #68b3a3; fill: #68b3a3; } /* Tradewind */
.q3 { background-color: #428476; fill: #428476; } /* Viridian */
.q4 { background-color: #264b44; fill: #264b44; } /* Plantation */

#map-controls {
    position: absolute;
    z-index: 49;
    top: 10px;
    left: 10px;
    background-color: #fff;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    border: 1px solid #014948;
    width: 450px;
    overflow-y: auto;
}
#locate #map-controls {
    overflow-y: visible;
}
#map-controls h1,
#map-controls .header-container {
    margin: .5em 0;
    clear: both;
    padding: 0;
}
#map-controls h2 span {
    margin-right: 1.5em;
}
#map-controls ul.metadata {
    line-height: 1.3;
    list-style: none;
    margin: 0 0 .8em;
    padding: 0;
}
#map-controls ul.metadata li {
    display: inline;
    font-size: .83em;
    margin-right: 1.5em;
}
#map-controls ul.metadata li.tool-group {
    margin-right: 0;
}
#map-controls ul.metadata li.bigger {
    font-weight: 700;
    font-size: .9em;
    margin-right: 1.2em;
}
#map-controls #map-legend,
#map-controls #column-select,
#map-controls #sumlev-select,
#map-controls .header-tool-set,
#map-controls aside {
    width: 100%;
    display: block;
    float: none;
}
#map-controls aside {
    padding: .67em 0 .33em;
    margin: 0;
}
#map-controls aside .action-button {
    float: right;
}
#map-controls #comparison-add-header,
#map-controls #query-topic-picker h1,
#map-controls #address-search-wrapper h1 {
    font-size: 1.3em;
}
#map-controls #map-legend,
#map-controls #column-select,
#map-controls #sumlev-select {
    clear: both;
    margin-top: 1em;
    display: none;
}
#map-controls #map-legend {
    margin: 2em 0;
    text-align: center;
}
#map-controls .header-tool-set,
#map-controls .caption {
    margin: .25em 0 0;
}
#map-legend,
#map-select {
    width: 50%;
    margin-right: 0;
    margin-bottom: 2em;
}
#map-legend {
    padding-right: 1.5em;
    font-size: 11px;
    height: 4em;
    float: right;
}
.leaflet-label.hovercard {
    white-space: normal;
    width: 250px;
}
.leaflet-label.hovercard .value {
    font-weight: normal;
}
.leaflet-label.hovercard {
    font-size: 13px;
    font-family: "Lato","Helvetica Neue",Helvetica,Arial,sans-serif;
    padding: .83em 1em;
}


ul.quantile-legend {
    list-style: none;
    margin: 0;
    position: relative;
}
.tool-group ul.quantile-legend {
    padding-bottom: 2em;
}
ul.quantile-legend li {
    height: 2.5em;
    width: 16.5%;
    position: relative;
    margin: 0;
}
#map-controls ul.quantile-legend {
    margin-left: -16.5%;
}
ul.quantile-legend span.quantile-label {
    position: absolute;
    bottom: -1.75em;
    width: 100%;
    left: 50%;
    text-align: center;
}

.map-layer path {
    fill: #000;
    fill-opacity: .2;
    stroke: #fff;
    stroke-width: 1.5px;
}

/* TABLES */
table {
    margin: 0 0 2em 0;
    font-size: .8em;
}
thead {
    border-bottom: 1px solid #d9ddca;
}
th {
    background-color: #eff1e9;
    min-width: 7em;
    vertical-align: bottom;
}
thead.left-align th {
    text-align: left;
}
th:first-child {
    -webkit-border-top-left-radius: 4px;
    -moz-border-radius-topleft: 4px;
    border-top-left-radius: 4px;
}
th:last-child {
    -webkit-border-top-right-radius: 4px;
    -moz-border-radius-topright: 4px;
    border-top-right-radius: 4px;
}
th, td {
    padding: .25em .75em;
}
td {
    vertical-align: top;
}
table .name {
    text-align: left;
    font-weight: 700;
    white-space: nowrap;
}
table .value {
    text-align: right;
}
tr:hover td,
tr.highlight td,
.grid .highlight,
.grid .hover {
    background-color: #e0e4d4;
}
table .percentage, table .raw-number {
    display: block
}
table .alt-number {
    display: none;
}
.indent-0 {
    padding-left: 0;
}
.indent-1 {
    padding-left: 1em;
}
.indent-2 {
    padding-left: 2em;
}
.indent-3 {
    padding-left: 3em;
}
.indent-4 {
    padding-left: 4em;
}
.indent-5 {
    padding-left: 5em;
}
.indent-6 {
    padding-left: 6em;
}
.indent-7 {
    padding-left: 7em;
}
td.indent-1 {
    padding-left: 1.75em;
}
td.indent-2 {
    padding-left: 2.75em;
}
td.indent-3 {
    padding-left: 3.75em;
}
td.indent-4 {
    padding-left: 4.75em;
}
td.indent-5 {
    padding-left: 5.75em;
}
td.indent-6 {
    padding-left: 6.75em;
}
td.indent-7 {
    padding-left: 7.75em;
}


form {
    margin: 0 0 2em;
}
form label {
    font-weight: bold;
}
input[type="text"],
select,
.select-wrapper,
.filter-group,
.item-chosen {
    background-color: #fff;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    border: 1px solid #cad0b5;
    height: 2.2em;
    line-height: 1em;
    padding: .5em;
}
form input[type="text"],
form select {
}
form select {
    padding: .5em .33em;
}

.select-wrapper select {
    width: 100%;
    background-color: transparent;
    background-color: rgba(0,0,0,0);
    border: 0;
    border-radius: 0;
    -webkit-appearance: none;
    cursor: pointer;
}
.select-wrapper select:focus {
    outline: 0;
}
.select-wrapper {
    position: relative;
    width: 100%;
    overflow: hidden;
    padding: 0;
}
.select-wrapper i.fa,
.filter-group i.fa, 
.item-chosen i.fa {
    position: absolute;
    top: 0;
    right: 0;
    padding: .5em .5em .25em;
    background-color: #fff;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
}
.select-wrapper i.fa:before,
.filter-group i.fa:before,
.item-chosen i.fa:before {
    cursor: pointer;
}

form.inline-form input,
form.inline-form select,
form.inline-form .select2-container {
    margin: 0 .5em;
}
.help-text {
    font-size: .83em;
    display: block;
    margin: .25em .75em;
}

tr.help-text {
    display: table-row;
}

.filter-group {
    font-size: 1em;
    cursor: pointer;
    position: relative;
    margin-bottom: .5em;
}
.filter-group.open {
    height: auto;
}
h3.filter-group-title,
h3.item-chosen-title {
    line-height: 1;
    font-size: 1em;
    margin-bottom: 0;
    padding-right: 1.5em;
}
.filter-group .filter-list {
    display: none;
    margin: .33em 0 0;
}
.filter-group.open .filter-list {
    display: block;
}
.filter-list a {
    cursor: pointer;
    text-decoration: none;
    font-weight: normal;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
}
.filter-list a.option-selected {
    color: #fff;
    background-color: #014948;
}
.filter-list {
    list-style: none;
    padding: 0;
    margin: 0 0 .75em;
}
.filter-list .label {
    font-size: .83em;
    font-weight: bold;
}
.filter-list a,
.filter-list .label {
    padding: .1em .33em;
    margin-left: -.33em;
}
p.filter-list a {
    margin: 0 0 0 .33em;
    padding: .1em .4em;
    font-size: .8em;
}

.filter-list ul {
    list-style: none;
    padding-left: .5em;
    margin: 0 0 .75em;
    line-height: 1.1;
}
.filter-list li {
    margin: .33em 0;
}
.filter-list label {
    font-weight: normal;
    padding-left: .25em;
}
.filter-list .group-label {
    font-weight: bold;
}
.topic-result {
    margin: .5em 0;
}
.topic-type {
    display: block;
    text-transform: uppercase;
    font-size: .75em;
    font-weight: bold;
    color: #aaa;
}
.select2-result:hover .topic-type {
    color: #eee;
}

textarea#results {
    width: 100%;
    height: 450px;
    padding: .5em;
}

.tool-set {
    float: right;
    padding-top: .1em;
    margin: -.1em 0 .5em 1.5em;
}
.tool-set.caption-tool-set {
    margin-top: .1em;
}
.tool-set .tool-group {
    float: left;
}
.tool-group {
    position: relative;
    margin-right: 1.5em;
    font-size: .83em;
}
.tool-group:last-child {
    margin-right: 0;
}
.header-tool-set .tool-group:last-child {
    margin-right: 1.5em;
}
.tool-group ul {
    list-style: none;
    margin: 0;
    padding: 0;
    display: inline;
}
.tool-group li {
    display: inline-block;
    margin: 0 0 0 .33em;
}
.tool-group .filter-list li {
    display: block;
    margin: .33em 0;
}
.tool-group a {
    cursor: pointer;
    text-decoration: underline;
}
.tool-group a:hover {
    color: #f55b2c;
}
.tool-group .filter-list a {
    text-decoration: none;
}
.tool-group input,
.tool-group select {
    display: inline;
    height: 2em;
    padding: .4em .33em;
    margin-left: .25em;
}
.tool-group.data-selector select {
    margin-left: 0;
    min-width: 150px;
    max-width: 450px;
}
.tool-group.data-selector .item-chosen {
    margin-left: 0;
    width: 100%;
    height: auto;
    position: absolute;
}
.tool-group .label {
    font-size: 1em;
    color: #aaa;
    font-weight: bold;
}

.item-chosen {
    cursor: pointer;
}
.item-chosen,
.item-choices {
    position: relative;
    background-color: #fff;
}
.item-choices {
    max-height: 200px;
    overflow-y: auto;
    margin-top: 1em;
    display: none;
    cursor: default;
}
.item-chosen.open {
    height: auto;
    z-index: 1001;
}
.item-chosen.open .item-choices {
    display: block;
}
/* handle hidden scrollbars in OS 10.7+ */
.item-choices::-webkit-scrollbar {
    -webkit-appearance: none;
}

.item-choices::-webkit-scrollbar:vertical {
    width: 11px;
}

.item-choices::-webkit-scrollbar:horizontal {
    height: 11px;
}

.item-choices::-webkit-scrollbar-thumb {
    border-radius: 8px;
    border: 2px solid white; /* should match background, can't be transparent */
    background-color: rgba(0, 0, 0, .5);
}

.header-tool-set {
    margin-top: .5em;
}
ul.toggle-set {
    display: block;
    font-size: 12px;
}
ul.toggle-set li {
    margin: 0;
    float: left;
    width: 90px;
    text-align: center;
    position: relative;
}
.toggle-set a {
    background-color: #a1d0c6;
    border-bottom: 1px solid #67b3a3;
    text-decoration: none;
    color: #888;
    margin-right: 1px;
}
.toggle-set a,
.toggle-sub-group a {
    padding: .25em 0 .33em;
    display: block;
}
.toggle-sub-group a {
    margin-top: .15em;
}
.toggle-set li:first-child a {
    -webkit-border-top-left-radius: 4px;
    -webkit-border-bottom-left-radius: 4px;
    -moz-border-radius-topleft: 4px;
    -moz-border-radius-bottomleft: 4px;
    border-top-left-radius: 4px;
    border-bottom-left-radius: 4px;
}
.toggle-set li:last-child a {
    -webkit-border-top-right-radius: 4px;
    -webkit-border-bottom-right-radius: 4px;
    -moz-border-radius-topright: 4px;
    -moz-border-radius-bottomright: 4px;
    border-top-right-radius: 4px;
    border-bottom-right-radius: 4px;
    border-right: 0;
}
.toggle-set a.active,
.toggle-set a:hover,
.toggle-set a.hovered {
    background-color: #1a9d95;
    color: #fff;
}
.toggle-set a.unhovered {
    background-color: #a1d0c6;
    color: #888;
}
ul.toggle-set .toggle-sub-group a:hover {
    -webkit-border-bottom-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    border-bottom-right-radius: 0;
}
.toggle-sub-group a:hover {
    color: #1a9d95;
}
ul.sub-group {
    display: none;
    position: absolute;
    top: 100%;
    left: 0;
    background-color: #fff;
    width: 100%;
    z-index: 99;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    border: 1px solid #e8eadf;
}
ul.sub-group li,
ul.sub-group a {
    margin: 0;
    display: block;
}
ul.sub-group li:first-child a {
    -webkit-border-top-right-radius: 4px;
    -webkit-border-top-left-radius: 4px;
    -moz-border-radius-topright: 4px;
    -moz-border-radius-topleft: 4px;
    border-top-right-radius: 4px;
    border-top-left-radius: 4px;
}
ul.sub-group li:last-child a {
    -webkit-border-bottom-right-radius: 4px;
    -webkit-border-bottom-left-radius: 4px;
    -moz-border-radius-bottomright: 4px;
    -moz-border-radius-bottomleft: 4px;
    border-bottom-right-radius: 4px;
    border-bottom-left-radius: 4px;
    border-bottom: none;
}
ul.sub-group a {
    text-decoration: none;
    padding: .33em .5em;
    border-bottom: 1px solid #e8eadf;
}
ul.sub-group a:hover {
    text-decoration: none;
    padding: .33em .5em;
    color: #fff;
    background-color: #1a9d95;
    border-color: #1a9d95;
}

/* CHARTS */

section.coal-chart-container {
    padding: 2em 0 4em;
    margin-bottom: 0;
}
section.chart-divider {
    margin: 1em 0 0;
    padding: 0.6em 0.75em;
    background-color: #f7f8f3;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    border-top: 1px solid #e8eadf;
    border-bottom: 1px solid #cad0b5;
}
section.chart-divider h2 {
    margin: 0;
    line-height: 1;
}
.coal-chart-container h2 {}
.coal-chart {
    list-style: none;
    position: relative;
    height: 10px;
    border-bottom: 1px solid #e5e5e5;
    margin: 0 1.5em;
}
.coal-chart li {
    display: inline;
    position: absolute;
    bottom: -6px;
    margin-left: -5px;
}
.coal-chart li .point {
    display: block;
    cursor: pointer;
    position: relative;
    height: 11px;
    width: 11px;
    color: #222;
    background-color: #eff1e9;
    border: 1px solid #acb58c;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
}
.coal-chart li .point:hover,
.coal-chart li .point.hovered {
    background-color: #42472e;
    border-color: #42472e;
    z-index: 3;
}
.coal-chart li .point.selected {
    background-color: #027b7a;
    border-color: #027b7a;
    z-index: 2;
}
.coal-chart li .point.selected.hovered {
    z-index: 4;
}
.coal-chart li .point .hovercard {
    position: absolute;
    width: 15em;
    bottom: 1.5em;
    right: -7.5em;
    font-size: .83em;
    line-height: 1.3;
    text-align: center;
    display: none;
    padding: .5em;
    border: 1px solid #e0e0e0;
    pointer-events: auto;
}
.coal-chart li .point:hover .hovercard,
.coal-chart li .point.hovered .hovercard,
.coal-chart li .point.selected .hovercard {
    display: block;
    background-color: #fff;
}
.coal-chart li.tick-mark {
    height: 26px;
    bottom: -13px;
    margin-left: 0;
    border-left: 1px solid #d5d5d5;
}
.coal-chart li.tick-mark.tick-mark-min {
    left: 0;
}
.coal-chart li.tick-mark.tick-mark-max {
    left: 100%;
}
.coal-chart li.tick-mark span {
    position: relative;
    font-size: .75em;
    display: block;
    color: #606060;
    padding: 0;
    margin-top: 26px;
    margin-left: -50%;
    white-space: nowrap;
}
.coal-chart li.tick-mark-min span {
    margin-left: -1px;
}
.coal-chart li.tick-mark-max span {
    margin-left: -99%;
}

.placeholder {
    background-color: #f5f5f5;
    color: #777;
    text-align: center;
    height: 200px;
    padding-top: 75px;
    border: 1px solid #777;
}

.comparison-builder {
    margin-bottom: 2em;
}
#query-builder #topic-picker,
#query-builder #geography-picker {
    display: none;
    clear: both;
    padding-top: 1em;
}

.change-button,
.go-button,
.action-button {
    font-family: "Lato", "Helvetica Neue", Helvetica, Arial, sans-serif;
    line-height: 1;
    cursor: pointer;
    text-align: center;
    padding: .7em 0;
    background-color: #1a9d95;
    color: #fff;
    text-decoration: none;
    font-size: 1.2em;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
}
.change-button {
    font-size: 1em;
    position: absolute;
    top: .5em;
    right: .5em;
    margin: 0;
    width: 10em;
}
.change-button:hover,
.action-button:hover {
    background-color: #f55b2c;
    color: #fff;
}

#topic-picker [class^="column-"],
#geography-picker [class^="column-"] {
    margin-bottom: 1em;
}

#query-builder-bar {
    position: relative;
    width: 100%;
    margin-bottom: 2em;
}
#query-builder-bar .leader {
    float: left;
    padding: .5em 0;
}
.float-query #query-builder-bar .leader {
    display: none;
}
#query-builder-bar h2 {
    font-size: 1em;
    line-height: 1.3;
    margin-bottom: 1em;
}
#query-builder-bar h4 {
    color: #aaa;
    margin-bottom: .5em;
}

#query-topic,
#query-geographies,
#query-release,
#query-go {
    float: left;
    width: 18%;
    margin-right: 3%;
    font-size: .83em;
}
#query-geographies {
    width: 42%;
}
#query-go {
    width: 13%;
    margin-right: 0;
    float: right;
}

#query-release {
    margin-right: 0;
}
#query-builder-bar .query-chosen {
    margin-left: 5em;
    text-align: center;
    height: 31px;
    padding: .5em 0 0;
    background-color: #fff;
    border: 1px solid #cad0b5;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    cursor: pointer;
}

#query-topic .query-chosen {
    margin-left: 4.5em;
}
#query-geographies .query-chosen {
    margin-left: 5.5em;
}
#query-release .query-chosen {
    margin-left: 6em;
}
#query-go .query-chosen {
    margin-left: 1em;
}

#query-builder-bar .query-chosen.tabbed.open,
#query-builder-bar .query-chosen.hovered,
#query-builder-bar .query-chosen.go,
.go-button {
    border-color: #014948;
    background-color: #014948;
    color: #fff;
    font-weight: 400;
}
#query-builder-bar .query-chosen.go,
.go-button {
    border-color: #f55b2c;
    background-color: #f55b2c;
}
#query-builder-bar .query-chosen.go:hover,
.go-button:hover {
    border-color: #f54814;
    background-color: #f54814;
}
#query-builder-bar .query-chosen.tabbed {
    -webkit-border-bottom-right-radius: 0;
    -webkit-border-bottom-left-radius: 0;
    -moz-border-radius-bottomright: 0;
    -moz-border-radius-bottomleft: 0;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}
#query-builder-bar .highlight,
#query-builder-bar .hover-only {
    text-transform: uppercase;
    font-weight: bold;
}
#query-go .highlight {
    font-weight: normal;
    text-transform: none;
}
#query-builder-bar .hover-only {
    display: none;
}
#query-builder-bar .query-chosen.hovered .hover-only {
    display: block;
}
#query-builder-bar .query-chosen.hovered .hover-hide {
    display: none;
}
#query-builder-bar  .disabled,
#query-builder-bar  .disabled:hover,
#query-builder-bar  .disabled.hovered,
.comparison-builder .disabled,
.comparison-builder .disabled:hover,
.comparison-builder .disabled.hovered {
    cursor: default;
    border-color: #baccc9;
    background-color: #baccc9;
    color: #fff;
}

#query-builder-bar section[id$="-picker"] {
    position: absolute;
    top: 30px;
    left: 0;
    width: 100%;
    background-color: #fff;
    display: none;
    z-index: 99;
    padding: 2% 0 2% 2%;
    border: 1px solid #001716;
    -webkit-border-bottom-right-radius: 4px;
    -webkit-border-bottom-left-radius: 4px;
    -moz-border-radius-bottomright: 4px;
    -moz-border-radius-bottomleft: 4px;
    border-bottom-right-radius: 4px;
    border-bottom-left-radius: 4px;
}
.release-option {
    text-align: center;
    font-size: .83em;
    margin-bottom: 3em;
}
.release-option p {
    margin: 0 0 1em;
}
.release-option a {
    text-decoration: none;
    padding: .33em 1em;
    background-color: #eff1e9;
    border-top: 1px solid #e8eadf;
    border-bottom: 1px solid #cad0b5;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
}
.release-option a:hover,
.release-option a.active {
    background-color: #d9ddca;
    color: #111;
}
.release-option a.disabled {
    cursor: default;
    background-color: #f0f0f0;
    border-top: 1px solid #eee;
    border-bottom: 1px solid #e0e0e0;
    color: #999;
}


#profile-topic-picker {
    width: 100%;
    margin-bottom: 0;
}
#chosen-table h2 {
    padding-left: 8px;
}
#chosen-table .data-drawer,
#data-tabular .data-drawer {
    padding-top: 0;
}

#glossary-card {
    width: 300px;
    text-align: left;
    padding: 1em 1.2em;
    pointer-events: auto;
}
#glossary-card small {
    float: right;
    cursor: pointer;
}
#glossary-card dt {
    font-weight: bold;
    font-size: 1.2em;
    margin-bottom: .5em;
}
#glossary-card dd {
    margin: 0;
}
#glossary-card p:last-child {
    margin-bottom: 0;
}
.glossary-term {
    border-bottom: 1px dashed #777;
    cursor: help;
}
#glossary header,
.topic header {
    margin: 1em 0 2em;
}
.example header {
    margin: 1em 0;
}
#glossary aside,
.topic aside {
    float: right;
    margin: 0 0 2em 2em;
    padding: 1em;
    background-color: #fff;
    -webkit-border-bottom-right-radius: 4px;
    -webkit-border-bottom-left-radius: 4px;
    -moz-border-radius-bottomright: 4px;
    -moz-border-radius-bottomleft: 4px;
    border-bottom-right-radius: 4px;
    border-bottom-left-radius: 4px;
    border-top: 1px solid #e8eadf;
    border-bottom: 1px solid #cad0b5;
}
#glossary aside h3,
.topic aside h3 {
    font-size: 1.1em;
}
#glossary aside ul {
    margin: 0;
    padding: 0 0 0 1.5em;
}
dl {
    clear: both;
    margin-top: 2em;
}
dl.glossary {
    clear: none;
}
dt {
    font-weight: bold;
    margin-bottom: .67em;
}
.topics dt {
    font-size: 1.5em;
}
dd {
    margin: 0 0 2em 1em;
}
.topic h2,
.example h2 {
    font-size: 1.4em;
}
.example h2 {
    margin-top: 1em;
}
.topic table {
    font-size: 1em;
    background-color: #fff;
    margin: 2em 0;
}
.topic table td {
    padding: .5em 1em;
}
.topic ul {
    line-height: 1.3;
}
.topic li {
    margin-bottom: .5em;
}
.topic aside {
    width: auto;
}
.topic aside img {
    width: 400px;
    margin-bottom: 1em;
}
#lightbox {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: rgba(0, 0, 0, .7);
    text-align: center;
    z-index: 999;
}
#lightbox .hovercard-wrapper {
    position: absolute;
    left: 50%;
}
#lightbox .hovercard {
    position: relative;
    left: -50%;
    margin-top: 100px;
    padding: 1.5em 2em;
    font-size: 1em;
    width: auto;
    pointer-events: auto;
}
#lightbox .close {
    display: block;
    float: right;
    margin-bottom: .75em;
    cursor: pointer;
}
#profile #lightbox .hovercard-wrapper {
    width: 600px;
}
#profile #lightbox .hovercard {
    text-align: left;
}
#profile #lightbox textarea {
    width: 100%;
    margin: 0 0 1em;
    padding: .5em;
    height: 7em;
}

code, pre {
    font-family: Monaco, "Bitstream Vera Sans Mono", "Lucida Console", Terminal;
    font-size: 14px;
}
code {
    background-color: #f7f7f7;
    border: solid 1px #ddd;
    padding: 0 .25em;
}
pre {
    -moz-border-radius: .25em;
    -webkit-border-radius: .25em;
    border-radius: .25em;
    text-shadow: none;
    overflow: auto;
    padding: 1.25em;
    margin-bottom: 2em;
    background-color: #002B36;
    color: #839496;
}
pre code {
    border: none;
    padding: 0;
    background-color: #002B36;
    color: #839496;
}
pre .hljs {
    padding: 0;
}

ul.compact * {
    margin: 0 inherit;
}

tfoot tr.help-text {
    padding: 1em 0 0 1em;
    line-height: 1.8;
}

dl#racial-iteration {
    padding-left: 1.5em;

}
dl#racial-iteration dt {
 font-weight: bold;
}

/* dl-horizontal borrowed with modifications from Twitter Bootstrap */
.dl-horizontal {
    *zoom: 1;
}
.dl-horizontal:before,
.dl-horizontal:after {
    display: table;
    content: "";
    line-height: 0;
}
.dl-horizontal:after {
    clear: both;
}
.dl-horizontal dt {
    float: left;
    clear: left;
    text-align: right;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}
.dl-horizontal dd {
    float: left;
    margin-left: .83em;
    margin-bottom: 1em;
}

@media (max-width: 767px) {
    .dl-horizontal dt {
        float: none;
        clear: both;
        width: auto;
        text-align: left;
        margin-bottom: .33em;
    }
    .dl-horizontal dd {
        margin-left: 0;
        margin-bottom: 1.5em;
    }
}
/* END dl-horizontal borrowed from Twitter Bootstrap */


/* AUTOCOMPLETE */
.tt-hint {
    visibility: hidden;
}

.tt-dropdown-menu {
    min-width: 160px;
    width: 100%;
    margin-top: 2px;
    padding: 0;
    background-color: #fff;
    border: 1px solid #ccc;
    *border-right-width: 2px;
    *border-bottom-width: 2px;
    -webkit-border-radius: 4px; -moz-border-radius: 4px; border-radius: 4px;
    height: 320px;
    overflow-y: auto;
}
.tt-dropdown-menu h2 {
    font-size: 1.2em;
    padding: .83em;
    margin-bottom: 0;
    background-color: #014948;
    color: #fff;
}
.tt-suggestion {
  display: block;
  padding: 1.25em .83em .83em;
  margin: 0;
  border-bottom: 1px solid #e0e0e0;
}

.tt-suggestion.tt-cursor {
  color: #fff;
  background-color: #027b7a;
  cursor: pointer;
}

.tt-suggestion h5,
.tt-suggestion p {
    line-height: 1.5;
    margin: 0 0 .5em;
    font-size: 1em;
}

.twitter-typeahead,
.twitter-typeahead .tt-query, 
.twitter-typeahead .tt-hint {
    width: 100%;
}

.tt-dataset-always .result-name {
    font-size: .83em;
}

#menu input,
#menu .tt-dropdown-menu {
    width: 240px;
}
#profile .content-container {
    padding-top: .5em;
}
#profile #query-topic-picker,
#profile #compare-place-picker {
    margin-bottom: 2em;
}
#profile #query-topic-picker h2,
#profile #compare-place-picker h2 {
    position: absolute;
    line-height: 1.8em;
    padding-left: .8em;
}
#profile #query-topic-picker .typeahead-container {
    width: 100%;
    padding-left: 12em;
}
#profile #compare-place-picker .typeahead-container {
    width: 100%;
    padding-left: 16em;
}
#query-topic-picker #topic-select,
#topic-picker #topic-select,
#compare-place-picker #compare-place-select {
    width: 100%;
}
aside .search .tt-dropdown-menu {
    font-size: .75em;
    top: 3em !important;
}
aside .search .result-type {
    float: none;
    display: block;
    margin: .25em 0 0;
    font-size: .9em;
}
.result-name .result-type {
    float: right;
    margin: .17em .33em 0 1em;
    font-size: .83em;
    font-style: italic;
}

/* !importants make me a little sad, but they're better than monkey-patching third-party code */
.twitter-typeahead .tt-query,
.twitter-typeahead .tt-hint {
    background-color: #fff !important;
    margin-bottom: 0;
}
.autocomplete-widget .tt-dropdown-menu {
    position: relative !important;
    display: block !important;
}
#page-header-title .tt-dropdown-menu {
    z-index: 1001 !important;
}
.autocomplete-widget input[disabled] {
    background-color: #eee !important;
}

.location-list {
    list-style: none;
    margin: 0;
    padding: 0;
    font-size: .9em;
}

.location-list a {
    text-decoration: none;
    background-color: #fff;
    display: block;
    font-weight: bold;
    padding: .67em .2em;
}
.location-list a:hover {
    color: #f55b2c;
}
.location-list .identifier {
    float: right;
    font-size: .83em;
    line-height: 1.9;
    font-weight: normal;
    font-style: italic;
    margin-left: .67em;
}
.location-list a:hover .identifier {
    color: #111;
}

#body-spinner {
    position: fixed;
    top: 0;
    left: 0;
    margin: 65px 20px;
    height: 20px;
    width: 20px;
    z-index: 100;
}

.message {
    margin: 0 0 2em;
    padding: .67em 0;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
}
.example,
.topic,
.message {
    max-width: 960px;
    margin-left: auto;
    margin-right: auto;
}

.message-error {
    padding: .67em 1em;
    background-color: #F5835D;
}
.message-help {
    padding: .67em 1em;
    background-color: #fff;
    border: 1px solid #e0e4d4;
}
blockquote {
    margin: 1em 0 2em;
    padding: 1em;
    background-color: #fff;
    border: 1px solid #CAD0B5;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
}


/* HELPERS */
.centered {
    text-align: center;
}
.smaller {
    font-size: .9em;
}
.small {
    font-size: .75em;
}
.strong {
    font-weight: bold;
}
.normal {
    font-weight: normal;
}
.bottom {
    margin-bottom: 0;
}
.hidden,
.geolocate-only,
.narrow-only {
    display: none;
}
.invisible {
    display: none !important;
    visibility: hidden;
}
.inactive,
.inactive a {
    color: #aaa;
}
.clear {
    clear: both;
}
.clearfix:before,
.clearfix:after {
    content: " ";
    display: table;
}
.clearfix:after {
    clear: both;
}
.clearfix {
    *zoom: 1;
}

/* MEDIA QUERIES */
@media only screen and (min-width: 1140px) {
    .wrapper {
        width: 1120px;
        margin: 0 auto;
    }
} /* END: @media only screen and (min-width: 1140px) */
@media only screen and (max-width: 1139px) {
    .chosen {
        margin: 0 0 1em;
    }
    
} /* END: @media only screen and (max-width: 1139px) */
@media only screen and (max-width: 768px) {
    article,
    article.column-full {
        margin-bottom: 2em;
    }
    header.section-contents {
        float: none;
        width: auto;
        margin: 0;
    }
    header.section-contents h1 {
        padding-left: 1.2em;
        margin-bottom: 0;
        border-bottom: none;
        -webkit-border-top-left-radius: 4px;
        -moz-border-radius-topleft: 4px;
        border-top-left-radius: 4px;
        -webkit-border-top-right-radius: 4px;
        -moz-border-radius-topright: 4px;
        border-top-right-radius: 4px;
        -webkit-border-bottom-left-radius: 0;
        -moz-border-radius-bottomleft: 0;
        border-bottom-left-radius: 0;
    }
    article .section-container {
        margin-top: 0;
        margin-left: 0;
        border-top: none;
        -webkit-border-top-right-radius: 0;
        -moz-border-radius-topright: 0;
        border-top-right-radius: 0;
    }
    section aside {
        float: none;
        margin-left: 0;
        width: auto;
        padding: 0;
    }
    aside .action-button {
        display: inline-block;
    }
    #glossary aside {
        float: right;
        margin: 0 0 2em 2em;
        padding: 1em;
        width: 200px;
    }
    aside ul.sumlev-list {
        margin: .33em 0;
    }
    aside ul.sumlev-list li {
        float: left;
        margin: 0 0 .67em .67em;
    }
    aside ul.sumlev-list li:last-child {
        margin-right: 1em;
    }
    #chosen-table h2 {
        padding-left: 0;
    }
    .column-full,
    .column-golden-wide,
    .column-golden-narrow {
        float: none;
        clear: both;
        width: auto;
        margin-right: 0;
    }
    .column-half .column-half {
        float: left;
        clear: none;
        width: 47%;
        margin-right: 3%;
    }
    .centered {
        text-align: left;
    }
    #cover-map {
        height: auto;
        margin: 1em;
        -webkit-border-radius: 4px;
        -moz-border-radius: 4px;
        border-radius: 4px;
    }
    #cover-map #slippy-map {
        height: 200px;
    }
    #cover-profile {
        margin: 200px 1em 0;
    }
    #cover-profile article {
        background-color: inherit;
        border: none;
        width: 100%;
        padding: 1em .25em;
        margin-top: 0;
    }
    #homepage #profile h1,
    #homepage #explore h1 {
        float: none;
        width: auto;
    }
    #homepage #geography-select {
        font-size: 1.6em;
        padding: .25em .5em 0;
        width: 100%;
    }
    #homepage .input-wrapper {
        padding-top: 0;
        padding-left: 0;
        margin-bottom: 1em;
    }
    #explore-topic-metadata p {
        width: auto;
        float: none;
        text-align: left;
        padding: 0 0 .25em 1em;
    }
    #homepage #geography-select-wrapper .action-button {
        font-size: 1.1em;
    }
    .card {
        font-size: 1em;
    }
    .topic aside img {
        width: 300px;
    }
    #header-container h1 {
        padding: 1em 0 0;
        clear: both;
    }
} /* END: @media only screen and (max-width: 768px) */
@media only screen and (max-width: 640px) {
    .tool-set {
        float: none;
        margin: .5em 0 1em;
    }
    #menu-toggle {
        display: block;
    }
    #menu {
        float: none;
        display: block;
        padding: 1em 0 .67em;
        display: none;
    }
    #menu input {
        margin-left: 0;
    }
    #menu input,
    #menu .tt-dropdown-menu {
        width: 100%;
    }
    #menu .tool-group {
        width: 47%;
    }
    #menu .separator {
        width: 6%;
    }
    #menu a.button i {
        display: inherit;
    }
    #menu .tt-dropdown-menu {
        height: 200px;
    }
    .section-container section,
    .stat-row [class^="column-"] {
        margin-bottom: 2em;
    }
    .stat-row [class^="column-"]:last-child {
        margin-bottom: 0;
    }
    .column-half,
    .column-two-thirds,
    .column-third,
    .column-three-quarters {
        float: none;
        clear: both;
        width: auto;
        margin-right: 0;
    }
    .column-quarter,
    .column-third.card {
        float: left;
        clear: none;
        width: 47%;
        margin-right: 3%;
    }
    #page-footer ul.ul-icon-list {
        text-align: left;
    }
    #page-footer li {
        margin-bottom: .5em;
    }
    #geography-picker .column-quarter,
    #query-geography-picker .column-quarter {
        width: 100%;
        font-size: 1.2em;
    }
    #geography-picker #sumlevs-standard,
    #query-geography-picker #sumlevs-standard {
        float: left;
        padding-right: 3em;
        margin-top: 0;
    }
    #geography-picker #sumlevs-schools,
    #query-geography-picker #sumlevs-schools {
        margin-top: 1.4em;
    }
    #profile #query-topic-picker .typeahead-container,
    #profile #compare-place-picker .typeahead-container
    {
        display: block;
        padding: 0 .75em;
    }
    #profile #query-topic-picker h2,
    #profile #compare-place h2
    {
        position: relative;
        margin-bottom: .33em;
    }
    #geography-picker li,
    #query-geography-picker li {
        margin-bottom: .67em;
    }
    #query-topic .query-chosen,
    #query-geographies .query-chosen,
    #query-release .query-chosen,
    #query-go .query-chosen {
        margin-left: 6em;
    }
    #query-builder-bar [id^="query-"] {
        margin-top: .5em;
    }
    #query-builder-bar section[id$="-picker"] {
        padding: 2%;
    }
    #query-builder-bar .leader {
        text-indent: .5em;
    }
    .topic aside img {
        width: 250px;
    }
    .header-container {
        padding-top: 1em;
    }
    #profile #compare-place-picker {
        display: none;
    }
} /* END: @media only screen and (max-width: 640px) */
@media only screen and (max-width: 480px) {
    .column-third,
    .column-half .column-half,
    .column-quarter,
    .column-third.card {
        float: none;
        clear: both;
        width: auto;
        margin-right: 0;
    }
    h1.title {
        font-size: 2em;
    }
    .stat .primary .value {
        font-size: 1.8em;
    }
    .stat .primary .name {
        font-size: 1.1em;
    }
    #menu {
        padding-top: 0;
    }
    #menu .tool-group {
        float: none;
        width: 100%;
        margin-right: 0;
        margin-top: 1em;
    }
    #menu .separator {
        display: none;
    }
    #cover-map #slippy-map {
        height: 150px;
    }
    #cover-profile {
        margin-top: 150px;
    }
    h1.article-header {
        font-size: 2.2em;
    }
    #homepage #geography-select,
    #homepage #topic-select {
        font-size: 1.2em;
    }
    .callout h3 {
        font-size: 21px;
    }
    #homepage .content-container {
        padding: 2em 0 1em;
    }
    #homepage .content-container:first-child {
        padding-top: 1em;
    }
    #geography-picker #sumlevs-standard {
        float: none;
        padding-right: .33em;
    }
    #geography-picker #sumlevs-schools {
        margin-top: .33em;
    }
    #glossary aside {
        float: none;
        margin: 0;
        padding: 1em;
        width: auto;
    }
    .wide-only {
        display: none;
    }
    .narrow-only {
        display: inline;
    }
    .topic aside {
        float: none;
        display: block;
        margin: 1em 0;
    }
    .topic aside img {
        width: 100%;
    }
}
@media only screen and (max-width: 360px) {
    h1.article-header {
        font-size: 2.2em;
    }
}
